### This display all variables

(see src/hatch_ci/tools.py:get_data)

- **ctx.version**  0.1.4b57
- **ctx.current**  0.1.4
- **ctx.ref**      refs/heads/beta/0.1.4
- **ctx.branch**   beta/0.1.4
- **ctx.sha**      8cdb40575b663d678dc080f07a1ac4c26096a795
- **ctx.build**    57
- **ctx.runid**    8317901778
- **ctx.workflow** beta